<p align="center">
    <a href="/sthali-core/images/sthali-core.svg">
        <img src="/sthali-core/images/sthali-core.svg" alt="sthali-core" height="35%">
    </a>
</p>

### WIP

A core package for Sthali development

---

### Requirements

#### Prerequisites
- `python >=3.10`
- `pip` package manager

#### Runtime Dependencies
This project requires the following Python packages with specific versions:

- `cookiecutter >= 2.6.0`

- `mkdocs >= 1.6.0`

- `PyYAML >= 6.0.2`

- `tomli >= 2.0.1`

- `typer >= 0.12.5`



#### Optional Dependencies
This project has optional dependencies that can be installed for additional features:

##### dev

- `coverage[toml] >= 7.6.1`

- `ruff >= 0.9.10`


##### tests

- `coverage[toml] >= 7.6.1`


##### stage

- `build >= 1.2.1`

- `coverage[toml] >= 7.6.1`



---

### Instalation

#### Using PYPI

```
pip install sthali-core
```

#### Using GitHub repo

```
git clone https://github.com/jhunufernandes/sthali-core.git
cd sthali-core
pip install .
```

---

### Usage

nothing to see here, plz disperse
